@@ -260,6 +260,11 @@ if (isset($params['submit']))
                         }
 			break;
 
+		      case 'quantity':
+			$v = (int)$v;
+			$v = max(0,$v);
+			break;
+
 		      case 'subscription':
 		      case 'dimensions':
 			if( is_array($v) )
@@ -281,7 +286,7 @@ if (isset($params['submit']))
 		      }
 
 		    // commit it.
-		    if( !is_null($v) && !empty($v) )
+		    if( !is_null($v) && $v !== '' )
 		      {
 			$query = 'INSERT INTO '.cms_db_prefix().'module_products_fieldvals (product_id, fielddef_id, value, create_date, modified_date) VALUES (?,?,?,?,?)';
 			$db->Execute($query, array($cid, $fid, $v, trim($db->DBTimeStamp(time()), "'"), trim($db->DBTimeStamp(time()), "'")));
@@ -301,7 +306,7 @@ if (isset($params['submit']))
 	  }
 		
 	//Update search index
-	$module =& $this->GetModuleInstance('Search');
+	$module = $this->GetModuleInstance('Search');
 	if ($module != FALSE)
 	  {
 	    if( $status == 'published' )
@@ -421,6 +426,11 @@ if (count($fielddefs) > 0)
 	    $field->input_box .= $this->CreateInputDropdown($id,'customfield[field-'.$fielddef->id.'][expire]',
 							   $expire_opts, -1, $value);
 	    break;
+
+	  case 'quantity':
+	    $field->input_box = $this->CreateInputText($id, 'customfield[field-'.$fielddef->id.']', $value, 4, 4);
+	    break;
+
 	  case 'textbox':
 	  default:
 	    $field->input_box = $this->CreateInputText($id, 'customfield[field-'.$fielddef->id.']', $value, 30, 255);
