@@ -109,9 +109,13 @@ if( isset($params['submit']) )
 	    $image = $res;
             if( $res === TRUE ) $image = '';
 
+	    $query = 'SELECT MAX(item_order)+1 FROM '.cms_db_prefix().'module_products_hierarchy WHERE parent_id = ?';
+	    $item_order = $db->GetOne($query,array($parent));
+	    if( !$item_order ) $item_order = 1;
+
 	    $query = 'INSERT INTO '.cms_db_prefix().'module_products_hierarchy
-                    (name, parent_id, description, image, extra1, extra2) VALUES(?,?,?,?,?,?)';
-	    $dbr = $db->Execute($query,array($name,$parent,$description,$image,$extra1,$extra2));
+                    (name, parent_id, description, image, extra1, extra2, item_order) VALUES(?,?,?,?,?,?,?)';
+	    $dbr = $db->Execute($query,array($name,$parent,$description,$image,$extra1,$extra2,$item_order));
 	    if( !$dbr ) { echo $db->sql.'<br/>'; die( $db->ErrorMsg() ); }
 	    $new_id = $db->Insert_ID();
 	    $this->UpdateHierarchyPositions();
