@@ -71,7 +71,7 @@ if (isset($params['detailpage']))
   {
     $detailpage = trim($params['detailpage']);
   }
-if( !empty($detailpage) )
+if( !empty($detailpage) && $detailpage != -1 )
   {
     $manager = $gCms->GetHierarchyManager();
     $node = $manager->sureGetNodeByAlias($detailpage);
@@ -434,15 +434,17 @@ if( $count % $limit != 0 ) $npages++;
 $config = cmsms()->GetConfig();
 while ($dbresult && ($row = $dbresult->FetchRow()))
 {
+  if( $detailpage == '' || $detailpage == -1 ) $detailpage = $returnid;
+
   $filedir = cms_join_path($config['uploads_path'],$this->GetName(),'product_'.$row['id']);
   $onerow = cge_array::to_object($row);
-  $prettyurl = product_ops::pretty_url($row['id'],($detailpage!='')?$detailpage:$returnid);
+  $prettyurl = product_ops::pretty_url($row['id'],$detailpage);
   
   $parms = $params;
   $parms['productid'] = $row['id'];
-  $onerow->detail_url = $this->CreateLink($id,'details',($detailpage!=''?$detailpage:$returnid),'',$parms,
+  $onerow->detail_url = $this->CreateLink($id,'details',$detailpage,'',$parms,
 					  '',true,$inline,'',false,$prettyurl);
-  $onerow->product_name_link = $this->CreateLink($id, 'details', $returnid, $row['product_name'], $parms);
+  $onerow->product_name_link = $this->CreateLink($id, 'details', $detailpage, $row['product_name'], $parms);
   $onerow->file_location = $config['uploads_url'].'/'.$this->GetName().'/product_'.$row['id'];
   $onerow->details = $row['details'];
 
