@@ -116,7 +116,7 @@ if ( $row )
 	$onerow->attributes = $tmp;
       }
 
-    $tmp = product_utils::get_product_attributes_full($params['product_id']);
+    $tmp = product_utils::get_product_attributes_full($params['productid']);
     if( is_array($tmp) )
       {
 	$onerow->attribs_full = $tmp;
@@ -137,16 +137,6 @@ if ( $row )
       }
     
     $smarty->assign_by_ref('entry', $onerow);
-    $cartmod = $this->GetPreference('cartmodule','');
-    if( !empty($cartmod) )
-      {
-	$cmparams = $this->GetPreference('cartmoduleparams','');
-	if( !empty($cmparams) )
-	  {
-	    $str = sprintf("{%s %s}",$cartmod,$cmparams);
-	    $smarty->assign('cart_module_tag',$str);
-	  }
-      }
     $smarty->assign('currency_symbol',product_ops::get_currency_symbol());
     $smarty->assign('weight_units',product_ops::get_weight_units());
     $smarty->assign('categorytext', implode(", ", $catnamearray));
