@@ -356,6 +356,11 @@ if (isset($params['submit']))
                       }
 		      break;
 
+		    case 'quantity':
+		      $v = (int)$v;
+		      $v = max(0,$v);
+		      break;
+		      
 		    case 'subscription':
 		    case 'dimensions':
 		      if( is_array($v) )
@@ -375,7 +380,7 @@ if (isset($params['submit']))
 		      break;
 		    }
 
-		  if( !is_null($v) && !empty($v) ) {		    
+		  if( !is_null($v) && $v !== '' ) {		    
 		    // commit it if there is a valid value
 		    $query = 'INSERT INTO '.cms_db_prefix().'module_products_fieldvals (product_id, fielddef_id, value, create_date, modified_date) VALUES (?,?,?,?,?)';
 		    $db->Execute($query, array($compid, $fid, $v, trim($db->DBTimeStamp(time()), "'"), trim($db->DBTimeStamp(time()), "'")));
@@ -396,7 +401,7 @@ if (isset($params['submit']))
 	  }
 		
 	//Update search index
-	$module =& $this->GetModuleInstance('Search');
+	$module = $this->GetModuleInstance('Search');
 	if ($module != FALSE)
 	  {
 	    $module->DeleteWords($this->GetName(), $compid, 'product');
@@ -568,6 +573,11 @@ if (count($fielddefs) > 0)
 	    $field->input_box .= $this->CreateInputDropdown($id,'customfield[field-'.$fielddef->id.'][expire]',
 							   $expire_opts, -1, $value['expire']);
 	    break;
+
+	  case 'quantity':
+	    $field->input_box = $this->CreateInputText($id, 'customfield[field-'.$fielddef->id.']', $value, 4, 4);
+	    break;
+
 	  case 'textbox':
 	  default:
 	    $field->input_box = $this->CreateInputText($id, 'customfield[field-'.$fielddef->id.']', $value, 30, 255);
@@ -635,13 +645,26 @@ $smarty->assign('inputstatus',
 
 $smarty->assign('idtext',$this->Lang('id'));
 $smarty->assign('compid',$compid);
-$this->smarty->assign('hidden', 
-		      $this->CreateInputHidden($id, 'compid', $compid).
-		      $this->CreateInputHidden($id, 'origname', $origname));
-$this->smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', lang('submit')));
-$this->smarty->assign('cancel', $this->CreateInputSubmit($id, 'cancel', lang('cancel')));
-$this->smarty->assign_by_ref('customfields', $fieldarray);
-$this->smarty->assign('customfieldscount', count($fieldarray));
+$smarty->assign('hidden', 
+		$this->CreateInputHidden($id, 'compid', $compid).
+		$this->CreateInputHidden($id, 'origname', $origname));
+$smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', lang('submit')));
+$smarty->assign('cancel', $this->CreateInputSubmit($id, 'cancel', lang('cancel')));
+$smarty->assign('customfields', $fieldarray);
+$smarty->assign('customfieldscount', count($fieldarray));
+
+$smarty->assign('starttabheaders',$this->StartTabHeaders());
+$smarty->assign('tabheader_main',$this->SetTabHeader('main',$this->Lang('product_info')));
+$smarty->assign('tabheader_fields',$this->SetTabHeader('fields',$this->Lang('fields')));
+$smarty->assign('tabheader_advanced',$this->SetTabHeader('advanced',$this->Lang('advanced')));
+$smarty->assign('endtabheaders',$this->EndTabHeaders());
+$smarty->assign('starttabcontent',$this->StartTabContent());
+$smarty->assign('tab_main',$this->StartTab('main'));
+$smarty->assign('tab_fields',$this->StartTab('fields'));
+$smarty->assign('tab_advanced',$this->StartTab('advanced'));
+$smarty->assign('endtab',$this->EndTab());
+$smarty->assign('endtabcontent',$this->EndTabContent());
+
 echo $this->ProcessTemplate('editproduct.tpl');
 
 ?>
