@@ -143,8 +143,7 @@ class productsCsvImporter
   {
     if( !is_array($this->_field_map) )
       {
-	global $gCms;
-	$db =& $gCms->GetDb();
+	$db = cmsms()->GetDb();
 	$query = 'SELECT id,name,type FROM '.cms_db_prefix().'module_products_fielddefs';
 	$tmp = $db->GetArray($query);
 	if( is_array($tmp) )
@@ -178,8 +177,7 @@ class productsCsvImporter
   {
     if( !is_array($this->_category_map) )
       {
-	global $gCms;
-	$db =& $gCms->GetDb();
+	$db = cmsms()->GetDb();
 	$query = 'SELECT id,name FROM '.cms_db_prefix().'module_products_categories';
 	$tmp = $db->GetArray($query);
 	if( is_array($tmp) )
@@ -198,8 +196,7 @@ class productsCsvImporter
   function __getHierarchyCache()
   {
     // make sure we have everything in memory.
-    global $gCms;
-    $db =& $gCms->GetDb();
+    $db = cmsms()->GetDb();
     $query = 'SELECT id,long_name FROM '.cms_db_prefix().'module_products_hierarchy';
     $tmp = $db->GetArray($query);
     if( is_array($tmp) )
@@ -220,8 +217,7 @@ class productsCsvImporter
 	if( (is_array($this->_hierarchy_map) && !isset($this->_hierarchy_map[$hier])) ||
 	    !is_array($this->_hierarchy_map) )
 	  {
-	    global $gCms;
-	    $db =& $gCms->GetDb();
+	    $db = cmsms()->GetDb();
 
 	    // we have everything in memory
 	    // it's just not there
@@ -329,8 +325,7 @@ class productsCsvImporter
 
   function _handleFirstLine()
   {
-    global $gCms;
-    $db =& $gCms->GetDb();
+    $db = cmsms()->GetDb();
     $now = $db->DbTimeStamp(time());
 
     // 0.  Get the field definitions
@@ -432,8 +427,7 @@ class productsCsvImporter
 
   function _handleNewProduct()
   {
-    global $gCms;
-    $db =& $gCms->GetDb();
+    $db = cmsms()->GetDb();
     $now = $db->DbTimeStamp(time());
 
     // get the info for the product
@@ -681,8 +675,7 @@ class productsCsvImporter
 
   function _testFirstLine(&$messages)
   {
-    global $gCms;
-    $db =& $gCms->GetDb();
+    $db = cmsms()->GetDb();
 
     for( $i = 0; $i < count($this->_record); $i++ )
       {
