@@ -113,7 +113,7 @@ if( isset($params['submit']) )
       {
 	$categories = array();
       }
-    $excludecats = (int)$params['input_excludecats'];
+    $excludecats = isset($params['input_excludecats'])?1:0;
 
     // store them as user preferences
     set_preference($uid,'products_sel_hierarchy',$hierarchy);
