@@ -38,7 +38,7 @@
 #END_LICENSE
 if (!isset($gCms)) exit;
 
-$db =& $this->GetDb();
+$db = $this->GetDb();
 
 $dict = NewDataDictionary($db);
 $taboptarray = array('mysql' => 'TYPE=MyISAM');
@@ -150,6 +150,7 @@ $dict->ExecuteSQLArray($sqlarray);
 $flds = "id I KEY AUTO,
          name C(255) NOT NULL,
          parent_id I,
+         item_order I,
          hierarchy C(255),
          image C(255),
          long_name X,
@@ -275,6 +276,9 @@ $this->SetPreference('allowed_filetypes','pdf,doc,txt,jpg,jpeg,gif,png');
 $this->SetPreference('autothumbnail',1);
 $this->SetPreference('deleteproductfiles',1);
 
+# Events
+$this->AddEventHandler('CGEcommerceBase','OrderUpdated',FALSE);
+
 #
 # EOF
 #
