@@ -38,7 +38,7 @@
 #END_LICENSE
 if (!isset($gCms)) exit;
 
-$db =& $this->GetDb();
+$db = $this->GetDb();
 
 $dict = NewDataDictionary( $db );
 
